@@ -1,4 +1,4 @@
-our $VERSION = '0.24';
+our $VERSION = '0.31';
 #the POD is at the end of this file
 #avoid shift() - it is computationally more expensive than pop
 #and shifting values for subroutine input should be avoided in
@@ -46,7 +46,7 @@ sub new {
 	return $self;
 }
 
-sub page {
+sub next {
 	my $self = shift;
 	my $buffer = $$self{BUFFER};
 	my $offset;
@@ -75,6 +75,7 @@ sub page {
 	return Parse::MediaWikiDump::page->new($data, $$self{CATEGORY_ANCHOR});
 }
 
+#outputs a nicely formated representation of the tokens on the buffer specified
 sub dump {
 	my $self = shift;
 	my $buffer = shift || $$self{BUFFER};
@@ -148,6 +149,14 @@ sub current_byte {
 	return $$self{BYTE};
 }
 
+#depreciated backwards compatibility methods
+
+#replaced by next()
+sub page {
+	my $self = shift;
+	return $self->next(@_);
+}
+
 #private functions with OO interface
 sub open {
 	my $self = shift;
@@ -387,6 +396,7 @@ sub parse_head {
 	return 1;
 }
 
+#this function is very frightning =)
 sub parse_page {
 	my $self = shift;
 	my $buffer = shift;
@@ -677,7 +687,8 @@ sub char_handler {
 		}
 
 		if ($ignore_ws_only) {
-			return 1 if $chars =~ m/^\s+$/m;
+			#non-breaking spaces are not whitespace in XML
+			return 1 if $chars =~ m/^[ \t\r\n]+$/m;
 		}
 
 		push(@$buffer, [T_TEXT, \$chars]);
@@ -692,7 +703,7 @@ use strict;
 use warnings;
 
 sub new {
-	my ($class, $data, $category_anchor) = @_; 
+	my ($class, $data, $category_anchor, $case_setting) = @_; 
 	my $self = {};
 
 	bless($self, $class);
@@ -750,7 +761,7 @@ sub redirect {
 
 	return $$self{CACHE}{redirect} if exists($$self{CACHE}{redirect});
 
-	if ($$text =~ m/^#redirect\s*\[\[([^\]]*)\]\]/i) {
+	if ($$text =~ m/^#redirect\s*:?\s*\[\[([^\]]*)\]\]/i) {
 		$$self{CACHE}{redirect} = $1;
 		return $1;
 	} else {
@@ -818,7 +829,7 @@ sub new {
 	return $self;
 }
 
-sub link {
+sub next {
 	my $self = shift;
 	my $buffer = $$self{BUFFER};
 	my $link;
@@ -891,6 +902,14 @@ sub init {
 	die "not a MediaWiki link dump file" unless $found;
 }
 
+#depreciated backwards compatibility methods
+
+#replaced by next()
+sub link {
+	my $self = shift;
+	$self->next(@_);
+}
+
 package Parse::MediaWikiDump::link;
 
 #you must pass in a fully populated link array reference
@@ -938,11 +957,11 @@ Parse::MediaWikiDump - Tools to process MediaWiki dump files
   $links = Parse::MediaWikiDump::Links->new($source);
 
   #get all the records from the dump files, one record at a time
-  while(defined($page = $pages->page)) {
+  while(defined($page = $pages->next)) {
     print "title '", $page->title, "' id ", $page->id, "\n";
   }
 
-  while(defined($link = $links->link)) {
+  while(defined($link = $links->next)) {
     print "link from ", $link->from, " to ", $link->to, "\n";
   }
 
@@ -1017,7 +1036,7 @@ After creation the folowing methods are avalable:
 
 =over 4
 
-=item $pages->page
+=item $pages->next
 
 Returns the next available record from the dump file if it is available,
 otherwise returns undef. Records returned are instances of 
@@ -1051,7 +1070,7 @@ namespace number and the second is the namespace name. In the case of namespace
 =head3 Parse::MediaWikiDump::page
 
 The Parse::MediaWikiDump::page object represents a distinct MediaWiki page, 
-article, module, what have you. These objects are returned by the page method
+article, module, what have you. These objects are returned by the next() method
 of a Parse::MediaWikiDump::Pages instance. The scalar returned is a reference
 to a hash that contains all the data of the page in a straightforward manor. 
 While it is possible to access this hash directly, and it involves less overhead
@@ -1113,10 +1132,10 @@ filehandle. For example:
   $links = Parse::MediaWikiDump::Links->new(\*FH);
 
 It is then possible to extract the links a single link at a time using the
-link method, which returns an instance of Parse::MediaWikiDump::link or undef
+next method, which returns an instance of Parse::MediaWikiDump::link or undef
 when there is no more data. For instance: 
 
-  while(defined($link = $links->link)) {
+  while(defined($link = $links->next)) {
     print 'from ', $link->from, ' to ', $link->to, "\n";
   }
 
@@ -1165,7 +1184,7 @@ The numerical id of the namespace the link points to.
   
   $title = case_fixer($title);
   
-  while(my $page = $dump->page) {
+  while(my $page = $dump->next) {
     if ($page->title eq $title) {
       print STDERR "Located text for $title\n";
       my $text = $page->text;
@@ -1229,7 +1248,7 @@ The numerical id of the namespace the link points to.
   
   print STDERR "Analyzing articles:\n";
   
-  while(defined($page = $pages->page)) {
+  while(defined($page = $pages->next)) {
     update_ui() if ++$artcount % 500 == 0;
   
     #main namespace only
@@ -1327,7 +1346,7 @@ The numerical id of the namespace the link points to.
 Currently the full page dump files (such as 20050909_pages_full.xml.gz) 
 are not supported.
 
-=item Optomization 
+=item Optimization
 
 It would be nice to increase the processing speed of the XML files. Current
 ideas:
@@ -1338,7 +1357,7 @@ ideas:
 
 Currently the base types for the majority of the classes are hashes. The 
 majority of these could be changed to arrays and numerical constants instead
-of using hashesh. 
+of using hashes. 
 
 =item Stackless parsing
 
@@ -1348,11 +1367,6 @@ of callbacks to use when it encounters each specific token.
 
 =back
 
-=item Testing
-
-This software has received only light testing consisting of multiple runs over
-the most recent English Wikipedia dump file: July 13, 2005. 
-
 =back
 
 =head1 AUTHOR
